@@ -9,7 +9,7 @@ Licence: GPLv3. See ../LICENCE '''
 
 from typing import Union
 from . import parser
-from . import request
+from . import mi
 
 
 class MiApi:
@@ -34,7 +34,7 @@ class MiApi:
         else it will return a MiError object with information about the error.
         '''
 
-        api = request.Api(self.ip, self.port, self.usr, self.pwd)
+        api = mi.Api(self.ip, self.port, self.usr, self.pwd)
         result = api.request(program, transaction, **kwargs)
 
         return parser.parse_mi_xml(result.content)
